@@ -2,6 +2,7 @@ import os
 
 import paramiko
 from bgutils.mysqlUtil import mysqlUtil
+from moviepy.editor import VideoFileClip
 
 
 class ftpUtil:
@@ -24,7 +25,14 @@ class ftpUtil:
         # remote_file = 项目ID(6位)+学生ID（11位）+文件ID(2位)+文件类型
         # 如P22001_20190010011_01.jpg
         try:
-            file_type = os.path.splitext(local_path)[-1]
+            ftype = os.path.splitext(local_path)[-1]
+            if ftype.upper()=='.MP4' or ftype.upper()=='.WMV':
+                clip=VideoFileClip()
+                duration=clip.duration
+                duration = 0
+            else:
+                duration=0
+            fsize=os.path.getsize(local_path)
             transport = paramiko.Transport((self.__hostname, self.__host_port))
             transport.connect(username=self.__username_stud, password=self.__password_stud)
             sftp = paramiko.SFTPClient.from_transport(transport)
@@ -37,7 +45,7 @@ class ftpUtil:
                 sftp.chdir(remotepath)
             stud = stud_id.zfill(11)
             no = no_file.zfill(8)
-            remote_file = prj + "_" + stud + "_" + no + file_type
+            remote_file = prj + "_" + stud + "_" + no + ftype
             sftp.put(local_path, remote_file)
             print('上传成功......')
             sftp.close()
@@ -51,7 +59,7 @@ class ftpUtil:
             # item['filename'] = local_path
             # item['url'] = self.__url_head+remote_file
             # item['stud'] = stud
-            self.__mutil.sftp_file_ins(local_path, self.__url_head +prj +'/'+ remote_file, stud,desc)
+            self.__mutil.sftp_file_ins(local_path, self.__url_head +prj +'/'+ remote_file, stud,desc,fsize,duration,ftype)
         except Exception as ex:
             print("日志记录出现如下异常%s" % ex)
 
